=============
BEMServer API
=============

.. image:: https://img.shields.io/pypi/v/bemserver-api.svg
    :target: https://pypi.org/project/bemserver-api/
    :alt: Latest version

.. image:: https://img.shields.io/pypi/pyversions/bemserver-api.svg
    :target: https://pypi.org/project/bemserver-api/
    :alt: Python versions

.. image:: https://github.com/BEMServer/bemserver-api/actions/workflows/build-release.yaml/badge.svg
    :target: https://github.com/bemserver/bemserver-api/actions?query=workflow%3ATests
    :alt: Build status

.. image:: https://codecov.io/gh/BEMServer/bemserver-api/branch/master/graph/badge.svg?token=4LRLMRA2S2
    :target: https://codecov.io/gh/bemserver/bemserver-api
    :alt: Code coverage

.. image:: https://readthedocs.org/projects/bemserver-docs/badge/
    :target: http://bemserver-docs.readthedocs.io/
    :alt: Documentation


BEMServer is a free Building Energy Management software platform.

Its purpose it to store data collected in buildings and produce useful information such as performance indicators or alerts.
